@@ -22,7 +22,8 @@ class Object(object):
 	def assign(self, dictionary):
 		if not isinstance(dictionary, dict):
 			raise TypeError("You can only self assign with a dictionary as parameter.")
-		return list(vars(self).keys())
+		for key,value in dictionary.items():
+			self[key] = value
 	# support item assignment.
 	def __setitem__(self, key, value):
 		setattr(self, key, value)
